This plots density estimates of the posterior distributions for repeatabilities, R&Rs, and proportions due to repeatability. This corresponds to Figure 5 from Culp, Ryan, Chen, and Hamada (2018). There will be a dark posterior predictive curve only if a random model was fit.
# S3 method for ordinalRR
density(x,plt.type=c("repeat", "rr", "prop", "all"),m=0, …)‘ordinalRR’ output from function ordinalRR().
‘character’ plot type (must be ‘repeat’, ‘rr’, ‘prop’, or ‘all’).
‘nonnegative integer’ relaxes the match criterion to within plus or minus m (see Equations (26) and (27) from Culp, Ryan, Chen, and Hamada, 2018).
mop up additional inputs.
Culp, S.L., Ryan, K.J., Chen, J., and Hamada, M.S. (2018). “Analysis of Repeatability and Reproducibility Studies with Ordinal Measurements.” Technometrics, doi:10.1080/00401706.2018.1429317.