Learn R Programming

ordinalRR (version 1.1)

hist.ordinalRR: Histogram for the latent part distributions from a Bayesian ordinal R&R analysis.

Description

This accepts an input of class ‘ordinalRR’ and constructs a plot of overlaid density estimates for the latent part qualities X[i] for i=1,2,...,I,I+1. Part I+1 is a new/hypothetical part with the standard normal distribution. For an example, run this package's demo or see Figure 4 from Culp, Ryan, Chen, and Hamada (2018).

Usage

# S3 method for ordinalRR
hist(x,x.low=-4,x.high=4,col="grey",...)

Arguments

x

‘ordinalRR’ output from function ordinalRR().

x.low

‘scalar’ lower bound for density support.

x.high

‘scalar’ upper bound for density support.

col

‘vector’ colors for density curves (can be a vector of color names or numbers of length 1 or I+1).

mop up additional inputs.

References

Culp, S.L., Ryan, K.J., Chen, J., and Hamada, M.S. (2018). “Analysis of Repeatability and Reproducibility Studies with Ordinal Measurements”. Technometrics, doi:10.1080/00401706.2018.1429317.

See Also

ordinalRR

Examples

Run this code
# NOT RUN {
   
# }
# NOT RUN {
      demo(ordinalRR)
   
# }

Run the code above in your browser using DataLab