Learn R Programming

ordinalRR (version 1.1)

print.ordinalRR: Print function for an object of class ordinalRR.

Description

This standard print function displays: the function call to ordinalRR() that produced this object and descriptions of the ordinal R&R data and its Bayesian posterior sample from JAGS.

Usage

# S3 method for ordinalRR
print(x,…)

Arguments

x

‘ordinalRR’ output from function ordinalRR().

mop up additional inputs.

See Also

ordinalRR

Examples

Run this code
# NOT RUN {
data(followup)
followup
x=preprocess(followup)
g.random<-ordinalRR(x)
print(g.random)
# }

Run the code above in your browser using DataLab