print.ordinalRR: Print function for an object of class ordinalRR.
Description
This standard print function displays: the function call to ordinalRR() that produced this object and descriptions of the ordinal R&R data and its Bayesian posterior sample from JAGS.